@@ -54,11 +54,6 @@ in this Software without prior written authorization from The Open Group.
 #include <X11/Xos.h>
 #include "misc.h"
 #include <X11/fonts/fontstruct.h>
-#include <X11/fonts/fontutil.h>
-
-/* Don't conflict with macros/prototypes in difsutils.h */
-#define _HAVE_XALLOC_DECLS
-#include <X11/fonts/fontmisc.h>
 
 #include "clientstr.h"
 #define FSMD_H
@@ -138,10 +133,9 @@ getCharInfos (
 	}
     }
 
-    xchars = (CharInfoPtr *) fsalloc (sizeof (CharInfoPtr) * nchars);
+    xchars = (CharInfoPtr *) FScalloc (nchars, sizeof (CharInfoPtr));
     if (!xchars)
 	return AllocError;
-    bzero (xchars, sizeof (CharInfoPtr) * nchars);
 
     if (ink_metrics)
 	metrics_func = (MetricsFunc)pfont->get_metrics;
@@ -174,7 +168,7 @@ getCharInfos (
 					    &glyphCount, xci);
 		if (err != Successful)
 		{
-		    fsfree (xchars);
+		    FSfree (xchars);
 		    return err;
 		}
 #if 0
@@ -201,7 +195,6 @@ GetExtents(
     unsigned long *num_extents,	/* return */
     fsXCharInfo **data)		/* return */
 {
-    unsigned long size;
     fsXCharInfo *ci;
     fsXCharInfo cilocal;
     char *pci;
@@ -218,10 +211,9 @@ GetExtents(
     if (err != Successful)
 	return err;
     
-    size = SIZEOF(fsXCharInfo) * nchars;
-    pci = (char *) fsalloc(size);
+    pci = (char *) FSallocarray(nchars, SIZEOF(fsXCharInfo));
     if (!pci) {
-	fsfree (xchars);
+	FSfree (xchars);
 	return AllocError;
     }
 
@@ -242,13 +234,78 @@ GetExtents(
 	pci += SIZEOF(fsXCharInfo);
     }
     
-    fsfree (xchars);
+    FSfree (xchars);
     
     *data = ci;
     
     return Successful;
 }
 
+static int
+CheckFSFormat(fsBitmapFormat format,
+	      fsBitmapFormatMask fmask,
+	      int *bit_order,
+	      int *byte_order,
+	      int *scan,
+	      int *glyph,
+	      int *image)
+{
+    /* convert format to what the low levels want */
+    if (fmask & BitmapFormatMaskBit) {
+	*bit_order = format & BitmapFormatBitOrderMask;
+	*bit_order = (*bit_order == BitmapFormatBitOrderMSB)
+	    	     ? MSBFirst : LSBFirst;
+    }
+    if (fmask & BitmapFormatMaskByte) {
+	*byte_order = format & BitmapFormatByteOrderMask;
+	*byte_order = (*byte_order == BitmapFormatByteOrderMSB)
+	    	      ? MSBFirst : LSBFirst;
+    }
+    if (fmask & BitmapFormatMaskScanLineUnit) {
+	*scan = format & BitmapFormatScanlineUnitMask;
+	/* convert byte paddings into byte counts */
+	switch (*scan) {
+	case BitmapFormatScanlineUnit8:
+	    *scan = 1;
+	    break;
+	case BitmapFormatScanlineUnit16:
+	    *scan = 2;
+	    break;
+	case BitmapFormatScanlineUnit32:
+	    *scan = 4;
+	    break;
+	default:
+	    return BadFontFormat;
+	}
+    }
+    if (fmask & BitmapFormatMaskScanLinePad) {
+	*glyph = format & BitmapFormatScanlinePadMask;
+	/* convert byte paddings into byte counts */
+	switch (*glyph) {
+	case BitmapFormatScanlinePad8:
+	    *glyph = 1;
+	    break;
+	case BitmapFormatScanlinePad16:
+	    *glyph = 2;
+	    break;
+	case BitmapFormatScanlinePad32:
+	    *glyph = 4;
+	    break;
+	default:
+	    return BadFontFormat;
+	}
+    }
+    if (fmask & BitmapFormatMaskImageRectangle) {
+	*image = format & BitmapFormatImageRectMask;
+
+	if (*image != BitmapFormatImageRectMin &&
+		*image != BitmapFormatImageRectMaxWidth &&
+		*image != BitmapFormatImageRectMax)
+	    return BadFontFormat;
+    }
+    return Successful;
+}
+
 static int
 packGlyphs (
     ClientPtr   client,
@@ -319,17 +376,17 @@ packGlyphs (
 	err = getCharInfos (pfont, num_ranges, range, TRUE, &nchars, &inkCharsFree);
 	if (err != Successful)
 	{
-	    fsfree (bitCharsFree);
+	    FSfree (bitCharsFree);
 	    return err;
 	}
 	reformat = TRUE;
     }
 
     /* get space for glyph offsets */
-    lengths = (fsOffset32 *) fsalloc(SIZEOF(fsOffset32) * nchars);
+    lengths = (fsOffset32 *) FSallocarray(nchars, SIZEOF(fsOffset32));
     if (!lengths) {
-	fsfree (bitCharsFree);
-	fsfree (inkCharsFree);
+	FSfree (bitCharsFree);
+	FSfree (inkCharsFree);
 	return AllocError;
     }
     
@@ -401,20 +458,19 @@ packGlyphs (
 	*data = gdata;
 	*tsize = size;
 	*offsets = lengths;
-	fsfree (bitCharsFree);
-	fsfree (inkCharsFree);
+	FSfree (bitCharsFree);
+	FSfree (inkCharsFree);
 	return Successful;
     }
     if (size)
     {
-	gdata = (pointer) fsalloc(size);
+	gdata = (pointer) FScalloc(1, size);
 	if (!gdata) {
-	    fsfree (bitCharsFree);
-	    fsfree (inkCharsFree);
-	    fsfree (lengths);
+	    FSfree (bitCharsFree);
+	    FSfree (inkCharsFree);
+	    FSfree (lengths);
 	    return AllocError;
 	}
-	bzero ((char *) gdata, size);
     }
     else
 	gdata = NULL;
@@ -597,8 +653,8 @@ packGlyphs (
 	else if (scanlineunit == 4)
 	    FourByteSwap(gdata, size);
     }
-    fsfree (bitCharsFree);
-    fsfree (inkCharsFree);
+    FSfree (bitCharsFree);
+    FSfree (inkCharsFree);
     *num_glyphs = nchars;
     *data = gdata;
     *tsize = size;
