@@ -291,36 +291,36 @@ ProcEstablishConnection(ClientPtr client)
     if (auth_index > 0)
     {
 	AuthContextPtr authp;
-	authp = (AuthContextPtr) fsalloc(sizeof(AuthContextRec));
+	authp = (AuthContextPtr) FSalloc(sizeof(AuthContextRec));
 	if (!authp) {
 	    SendErrToClient(client, FSBadAlloc, (pointer) 0);
 	    DEALLOCATE_LOCAL(client_auth);
 	    return FSBadAlloc;
 	}
 	authp->authname =
-	    (char *) fsalloc(client_auth[auth_index - 1].namelen + 1);
+	    (char *) FSalloc(client_auth[auth_index - 1].namelen + 1);
 	authp->authdata =
-	    (char *) fsalloc(client_auth[auth_index - 1].datalen + 1);
+	    (char *) FSalloc(client_auth[auth_index - 1].datalen + 1);
 	if (!authp->authname || !authp->authdata) {
-	    fsfree((char *) authp->authname);
-	    fsfree((char *) authp->authdata);
-	    fsfree((char *) authp);
+	    FSfree((char *) authp->authname);
+	    FSfree((char *) authp->authdata);
+	    FSfree((char *) authp);
 	    SendErrToClient(client, FSBadAlloc, (pointer) 0);
 	    DEALLOCATE_LOCAL(client_auth);
 	    return FSBadAlloc;
 	}
-	memmove( authp->authname, client_auth[auth_index - 1].name, 
+	memcpy(authp->authname, client_auth[auth_index - 1].name,
 	      client_auth[auth_index - 1].namelen);
-	memmove( authp->authdata, client_auth[auth_index - 1].data, 
+	memcpy(authp->authdata, client_auth[auth_index - 1].data,
 	      client_auth[auth_index - 1].datalen);
 	/* Save it with a zero resource id...  subsequent
 	   SetAuthorizations of None will find it.  And it will be freed
 	   by FreeClientResources when the connection closes.  */
 	if (!AddResource(client->index, 0, RT_AUTHCONT,(pointer) authp)) 
 	{
-	    fsfree((char *) authp->authname);
-	    fsfree((char *) authp->authdata);
-	    fsfree((char *) authp);
+	    FSfree((char *) authp->authname);
+	    FSfree((char *) authp->authdata);
+	    FSfree((char *) authp);
 	    SendErrToClient(client, FSBadAlloc, (pointer) 0);
 	    DEALLOCATE_LOCAL(client_auth);
 	    return FSBadAlloc;
@@ -362,7 +362,7 @@ ProcEstablishConnection(ClientPtr client)
 	/* WriteToClient pads, so we have to fake some things */
 	tmp[0] = altservers[i].subset;
 	tmp[1] = altservers[i].namelen;
-	memmove( (char *) &tmp[2], altservers[i].name, altservers[i].namelen);
+	memcpy(&tmp[2], altservers[i].name, altservers[i].namelen);
 	(void) WriteToClient(client, altservers[i].namelen + 2, tmp);
     }
 
@@ -494,7 +494,7 @@ ProcListCatalogues(ClientPtr client)
 
     WriteReplyToClient(client, SIZEOF(fsListCataloguesReply), &rep);
     (void) WriteToClient(client, len, (char *) catalogues);
-    fsfree((char *) catalogues);
+    FSfree((char *) catalogues);
     return client->noClientException;
 }
 
@@ -517,17 +517,17 @@ ProcSetCatalogues(ClientPtr client)
 	err = ValidateCatalogues(&num, (char *)stuff + SIZEOF(fsSetCataloguesReq));
 	if (err == FSSuccess) {
 	    len = (stuff->length << 2) - SIZEOF(fsSetCataloguesReq);
-	    new_cat = (char *) fsalloc(len);
+	    new_cat = (char *) FSalloc(len);
 	    if (!new_cat)
 		return FSBadAlloc;
-	    memmove( new_cat, (char *)stuff + SIZEOF(fsSetCataloguesReq), len);
+	    memcpy(new_cat, (char *)stuff + SIZEOF(fsSetCataloguesReq), len);
 	} else {
 	    SendErrToClient(client, err, (pointer) &num);
 	    return err;
 	}
     }
     if (client->catalogues)
-	fsfree((char *) client->catalogues);
+	FSfree((char *) client->catalogues);
     client->catalogues = new_cat;
     client->num_catalogues = num;
     return client->noClientException;
@@ -641,7 +641,7 @@ ProcCreateAC(ClientPtr client)
 	    DEALLOCATE_LOCAL(acp);
 	return err;
     }
-    authp = (AuthContextPtr) fsalloc(sizeof(AuthContextRec));
+    authp = (AuthContextPtr) FSalloc(sizeof(AuthContextRec));
     if (!authp) {
 	goto alloc_failure;
     }
@@ -649,16 +649,16 @@ ProcCreateAC(ClientPtr client)
     authp->authdata = NULL;
     if (index > 0)
     {
-	authp->authname = (char *) fsalloc(acp[index - 1].namelen + 1);
-	authp->authdata = (char *) fsalloc(acp[index - 1].datalen + 1);
+	authp->authname = (char *) FSalloc(acp[index - 1].namelen + 1);
+	authp->authdata = (char *) FSalloc(acp[index - 1].datalen + 1);
 	if (!authp->authname || !authp->authdata) {
-	    fsfree((char *) authp->authname);
-	    fsfree((char *) authp->authdata);
-	    fsfree((char *) authp);
+	    FSfree((char *) authp->authname);
+	    FSfree((char *) authp->authdata);
+	    FSfree((char *) authp);
 	    goto alloc_failure;
 	}
-	memmove( authp->authname, acp[index - 1].name, acp[index - 1].namelen);
-	memmove( authp->authdata, acp[index - 1].data, acp[index - 1].datalen);
+	memcpy(authp->authname, acp[index - 1].name, acp[index - 1].namelen);
+	memcpy(authp->authdata, acp[index - 1].data, acp[index - 1].datalen);
     }
     else
 	size = 0;
@@ -696,10 +696,10 @@ DeleteAuthCont (pointer value, FSID id)
     AuthContextPtr  authp = (AuthContextPtr) value;
 
     if (authp->authname)
-	fsfree (authp->authname);
+	FSfree (authp->authname);
     if (authp->authdata)
-	fsfree (authp->authdata);
-    fsfree (authp);
+	FSfree (authp->authdata);
+    FSfree (authp);
     return 1;
 }
 
@@ -757,13 +757,13 @@ ProcSetResolution(ClientPtr client)
 	return FSBadLength;
     }
     new_res = (fsResolution *)
-	fsalloc(SIZEOF(fsResolution) * stuff->num_resolutions);
+	FSallocarray(stuff->num_resolutions, SIZEOF(fsResolution));
     if (!new_res) {
 	SendErrToClient(client, FSBadAlloc, NULL);
 	return FSBadAlloc;
     }
-    fsfree((char *) client->resolutions);
-    memmove( (char *) new_res, (char *)stuff + SIZEOF(fsSetResolutionReq), 
+    FSfree((char *) client->resolutions);
+    memcpy(new_res, (char *)stuff + SIZEOF(fsSetResolutionReq),
 	  (stuff->num_resolutions * SIZEOF(fsResolution)));
     client->resolutions = new_res;
     client->num_resolutions = stuff->num_resolutions;
@@ -917,7 +917,7 @@ ProcQueryXInfo(ClientPtr client)
 	SwapPropInfo(prop_info);
     (void) WriteToClient(client, lendata, (char *) prop_info);
 
-    fsfree((char *) prop_info);
+    FSfree((char *) prop_info);
     return client->noClientException;
 }
 
@@ -1045,7 +1045,7 @@ DoCloseDownClient(ClientPtr client)
 
 	if (currentClient == client)
 	    currentClient = serverClient;
-	fsfree(client);
+	FSfree(client);
 
 #ifdef DEBUG
 	fprintf(stderr, "Shut down client\n");
@@ -1075,12 +1075,9 @@ InitProcVectors(void)
     for (i = 0; i < NUM_PROC_VECTORS; i++) {
 	if (!ProcVector[i]) {
 	    ProcVector[i] = SwappedProcVector[i] = ProcBadRequest;
-	    ReplySwapVector[i] = (ReplySwapFunc)NotImplemented;
+	    ReplySwapVector[i] = ReplySwapNotImplemented;
 	}
     }
-    for (i = FSLASTEvent; i < NUM_EVENT_VECTORS; i++) {
-	EventSwapVector[i] = (EventSwapFunc)NotImplemented;
-    }
 }
 
 void
@@ -1120,21 +1117,21 @@ NextAvailableClient(pointer ospriv)
     if (i == MaxClients)
 	return NullClient;
 
-    clients[i] = client = (ClientPtr) fsalloc(sizeof(ClientRec));
+    clients[i] = client = (ClientPtr) FSalloc(sizeof(ClientRec));
     if (!client)
 	return NullClient;
 
     InitClient(client, i, ospriv);
 
     if (!InitClientResources(client)) {
-	fsfree(client);
+	FSfree(client);
 	return NullClient;
     }
     data.reqType = 1;
     data.length = (sizeof(fsFakeReq) + SIZEOF(fsConnClientPrefix)) >> 2;
     if (!InsertFakeRequest(client, (char *) &data, sizeof(fsFakeReq))) {
 	FreeClientResources(client);
-	fsfree(client);
+	FSfree(client);
 	return NullClient;
     }
     if (i == currentMaxClients)
