@@ -58,6 +58,7 @@ in this Software without prior written authorization from The Open Group.
 #include        "closestr.h"
 #include        "globals.h"
 #include	"difs.h"
+#include        "misc.h"
 #include	"dispatch.h"
 #include	<swapreq.h>
 #include	<swaprep.h>
@@ -82,7 +83,7 @@ convert_props(
 {
     int i;
     int data_len, cur_off;
-    char *str;
+    const char *str;
     pointer ptr, off_ptr, string_base;
     fsPropOffset local_offset;
 
@@ -100,7 +101,7 @@ convert_props(
     /*
      * allocate the single chunk that the difs layer requires
      */
-    ptr = (pointer) fsalloc(SIZEOF(fsPropInfo)
+    ptr = (pointer) FSalloc(SIZEOF(fsPropInfo)
 			    + SIZEOF(fsPropOffset) * pinfo->nprops
 			    + data_len);
     if (!ptr)
@@ -180,7 +181,7 @@ build_range(
 
 	if (src_num >= SIZE_MAX / sizeof(fsRange) * 2 - 1) 
 		return NULL;
-	np = new = (fsRange *) fsalloc(sizeof(fsRange) * (src_num + 1) / 2);
+	np = new = (fsRange *) FSalloc(sizeof(fsRange) * (src_num + 1) / 2);
 	if (!np)
 	    return np;
 	/* Build a new range */
@@ -211,7 +212,7 @@ build_range(
 	src_num = *num;
 	if (src_num >= SIZE_MAX / sizeof(fsRange)) 
 		return NULL;
-	np = new = (fsRange *) fsalloc(SIZEOF(fsRange) * src_num);
+	np = new = (fsRange *) FSallocarray(src_num, SIZEOF(fsRange));
 	if (!np)
 	    return np;
 
@@ -292,14 +293,14 @@ do_query_extents(ClientPtr client, pointer data)
 	    SwapExtents(extents, num_extents);
 	WriteReplyToClient(pPtr->client, SIZEOF(fsQueryXExtents8Reply), &reply);
 	WriteToClient(pPtr->client, lendata, (char *) extents);
-	fsfree((char *) extents);
+	FSfree((char *) extents);
     }
     if (pPtr->slept)
 	ClientWakeup(pPtr->client);
     if (pPtr->pfont->unload_glyphs)  /* For rasterizers that want to save memory */
 	(*pPtr->pfont->unload_glyphs)(pPtr->pfont);
-    fsfree(pPtr->range);
-    fsfree(pPtr);
+    FSfree(pPtr->range);
+    FSfree(pPtr);
     return TRUE;
 }
 
@@ -326,9 +327,11 @@ QueryExtents(
 	SendErrToClient(client, FSBadRange, NULL);
 	return FSBadRange;
     }
-    c = (QEclosurePtr) fsalloc(sizeof(QEclosureRec));
-    if (!c)
+    c = (QEclosurePtr) FSalloc(sizeof(QEclosureRec));
+    if (!c) {
+	FSfree(fixed_range);
 	return FSBadAlloc;
+    }
     c->client = client;
     c->slept = FALSE;
     c->pfont = cfp->font;
@@ -386,16 +389,16 @@ do_query_bitmaps(ClientPtr client, pointer data)
 	WriteToClient(pPtr->client, (num_glyphs * SIZEOF(fsOffset32)),
 		      (char *) offsets);
 	WriteToClient(pPtr->client, data_size, (char *) glyph_data);
-	fsfree((char *) offsets);
+	FSfree((char *) offsets);
 	if (freedata)
-	    fsfree((char *) glyph_data);
+	    FSfree((char *) glyph_data);
     }
     if (pPtr->slept)
 	ClientWakeup(pPtr->client);
     if (pPtr->pfont->unload_glyphs)  /* For rasterizers that want to save memory */
 	(*pPtr->pfont->unload_glyphs)(pPtr->pfont);
-    fsfree(pPtr->range);
-    fsfree(pPtr);
+    FSfree(pPtr->range);
+    FSfree(pPtr);
     return TRUE;
 }
 
@@ -423,9 +426,11 @@ QueryBitmaps(
 	SendErrToClient(client, FSBadRange, NULL);
 	return FSBadRange;
     }
-    c = (QBclosurePtr) fsalloc(sizeof(QBclosureRec));
-    if (!c)
+    c = (QBclosurePtr) FSalloc(sizeof(QBclosureRec));
+    if (!c) {
+	FSfree(fixed_range);
 	return FSBadAlloc;
+    }
     c->client = client;
     c->slept = FALSE;
     c->pfont = cfp->font;
